@@ -10,8 +10,7 @@ SpatialPixelsDataFrame = function(points, data,
 	new("SpatialPixelsDataFrame", points, data = data)
 }
 
-SpatialGridDataFrame = function(grid, data, 
-		proj4string = CRS(as.character(NA))) {
+SpatialGridDataFrame = function(grid, data, proj4string = CRS(as.character(NA))) {
 	if (!is(grid, "SpatialGrid"))
 		grid = SpatialGrid(grid, proj4string)
 	new("SpatialGridDataFrame", grid, data = data)
@@ -58,8 +57,8 @@ as.SGDF.SPixDF = function(from) {
 	new("SpatialPixelsDataFrame", 
 		new("SpatialPixels", 
 			new("SpatialPoints", coords = coordinates(from)[sel,], 
-				bbox = from@bbox, proj4string = CRS(proj4string(from))),
-			grid = from@grid, 
+				bbox = from@bbox, proj4string = from@proj4string),
+			grid = from@grid,
 			grid.index = which(sel)),
 		data = from@data[sel,,drop=FALSE])
 }
@@ -231,9 +230,13 @@ subs.SpatialGridDataFrame <- function(x, i, j, ... , drop = FALSE) {
 	idx = as.vector(m) # t(m)?
 	if (any(is.na(idx)))
 		stop("NAs not permitted in index")
-	pts = SpatialPoints(coordinates(x)[idx,], CRS(proj4string(x)))
-	res = SpatialPixelsDataFrame(SpatialPixels(pts), x@data[idx, k, drop = FALSE])
-	as(res, "SpatialGridDataFrame")
+	pts = SpatialPoints(coordinates(x)[idx,,drop=FALSE], CRS(proj4string(x)))
+	if (length(idx) == 1)
+		SpatialPointsDataFrame(pts, x@data[idx, k, drop = FALSE])
+	else {
+		res = SpatialPixelsDataFrame(SpatialPixels(pts), x@data[idx, k, drop = FALSE])
+		as(res, "SpatialGridDataFrame")
+	}
 }
 setMethod("[", "SpatialGridDataFrame", subs.SpatialGridDataFrame)
 
